'use strict'

const Redis = require('redis')
const util = require('util')

function promisifyAll(target) {
    for (let n in target) {
        let member = target[n]
        if (typeof (member) === 'function') {
            target[n + 'Async'] = util.promisify(member)
        }
    }
}

promisifyAll(Redis.RedisClient.prototype)
promisifyAll(Redis.Multi.prototype)

const RedisPool = require('./pool-client')

function createPool(clientOptions, poolOptions) {
    return new RedisPool(clientOptions, poolOptions)
}

const mod = {
    createClient: Redis.createClient,
    RedisClient: Redis.RedisClient,
    print: Redis.print,
    Multi: Redis.Multi,
    RedisPool,
    createPool
}

Object.defineProperty(mod, 'debug_mode', {
    get() {
        return Redis.debug_mode
    },
    set(v) {
        Redis.debug_mode = v
    }
})

module.exports = mod